##################
Glossary
##################

.. glossary::
    :sorted:

    structured logging
        logging information in easy-to-parse key-value pairs, instead of embedded in a human-readable message. See an :ref:`example <structured-logging>`
    asynchronous logging
        performance enhancement that moves formatting and writing messages to a separate process. See :ref:`async-logging`.
